@@ -23,7 +23,7 @@ heckit5fit <- function(selection, outcome1, outcome2,
       return(TRUE)
    }
    ## Do a few sanity checks...
-   if( class( selection ) != "formula" ) {
+   if( ! inherits( selection, "formula" ) ) {
       stop( "argument 'selection' must be a formula" )
    }
    if( length( selection ) != 3 ) {
